==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects.md <==
# AmazonSimpleStorageServiceBucketWithObjects


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')
```



| Illustration | AmazonSimpleStorageServiceBucketWithObjects | AmazonSimpleStorageServiceBucketWithObjectsCard | AmazonSimpleStorageServiceBucketWithObjectsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects.png) | ![illustration for AmazonSimpleStorageServiceBucketWithObjects](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects.Local.png) | ![illustration for AmazonSimpleStorageServiceBucketWithObjectsCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjectsCard.Local.png) | ![illustration for AmazonSimpleStorageServiceBucketWithObjectsGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjectsGroup.Local.png) |




## AmazonSimpleStorageServiceBucketWithObjects

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjects
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjects('AmazonSimpleStorageServiceBucketWithObjects', 'Amazon Simple Storage Service Bucket With Objects', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjects
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjects('AmazonSimpleStorageServiceBucketWithObjects', 'Amazon Simple Storage Service Bucket With Objects', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceBucketWithObjectsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjectsCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjectsCard('AmazonSimpleStorageServiceBucketWithObjectsCard', 'Amazon Simple Storage Service Bucket With Objects Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjectsCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjectsCard('AmazonSimpleStorageServiceBucketWithObjectsCard', 'Amazon Simple Storage Service Bucket With Objects Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceBucketWithObjectsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjectsGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjectsGroup('AmazonSimpleStorageServiceBucketWithObjectsGroup', 'Amazon Simple Storage Service Bucket With Objects Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjectsGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjectsGroup('AmazonSimpleStorageServiceBucketWithObjectsGroup', 'Amazon Simple Storage Service Bucket With Objects Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects.md <==
# AmazonSimpleStorageServiceBucketWithObjects


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')
```



| Illustration | AmazonSimpleStorageServiceBucketWithObjects | AmazonSimpleStorageServiceBucketWithObjectsCard | AmazonSimpleStorageServiceBucketWithObjectsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects.png) | ![illustration for AmazonSimpleStorageServiceBucketWithObjects](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects.Local.png) | ![illustration for AmazonSimpleStorageServiceBucketWithObjectsCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjectsCard.Local.png) | ![illustration for AmazonSimpleStorageServiceBucketWithObjectsGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjectsGroup.Local.png) |




## AmazonSimpleStorageServiceBucketWithObjects

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjects
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjects('AmazonSimpleStorageServiceBucketWithObjects', 'Amazon Simple Storage Service Bucket With Objects', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjects
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjects('AmazonSimpleStorageServiceBucketWithObjects', 'Amazon Simple Storage Service Bucket With Objects', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceBucketWithObjectsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjectsCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjectsCard('AmazonSimpleStorageServiceBucketWithObjectsCard', 'Amazon Simple Storage Service Bucket With Objects Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjectsCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjectsCard('AmazonSimpleStorageServiceBucketWithObjectsCard', 'Amazon Simple Storage Service Bucket With Objects Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceBucketWithObjectsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjectsGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjectsGroup('AmazonSimpleStorageServiceBucketWithObjectsGroup', 'Amazon Simple Storage Service Bucket With Objects Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceBucketWithObjectsGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceBucketWithObjects')

' renders the element
AmazonSimpleStorageServiceBucketWithObjectsGroup('AmazonSimpleStorageServiceBucketWithObjectsGroup', 'Amazon Simple Storage Service Bucket With Objects Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
